From fe612e5c8e897cf4741a929668aabac393c510d7 Mon Sep 17 00:00:00 2001
From: Michael Darling <darlingm@gmail.com>
Date: Thu, 16 Jul 2015 22:23:26 -0400
Subject: [PATCH] [2/14] Completes renaming of configure.in files to .ac

Combined builds has been broken for about 10 months, because some binutils
configure.in files were renamed to configure.ac, but gcc's references to them
were not updated.  Fixing gcc's references to them is much easier by renaming
the few straggling configure.in files to configure.ac. gcc's configure.in
files were entirely renamed to configure.ac some time ago. There are
corresponding patches submitted to gcc, which updates all references to
binutils-gdb configure.in files to configure.ac, which is what ultimately
fixes combined builds.

See PR binutils-gdb/binutils/18450 and gcc/other/66259.

Signed-off by: Michael Darling <darlingm@gmail.com>
---
 bfd/ChangeLog     | 6 ++++++
 bfd/configure     | 4 ++--
 bfd/configure.com | 6 +++---
 3 files changed, 11 insertions(+), 5 deletions(-)

diff --git a/bfd/ChangeLog b/bfd/ChangeLog
index 0d99205..29b265b 100644
--- a/bfd/ChangeLog
+++ b/bfd/ChangeLog
@@ -1,3 +1,9 @@
+2015-07-16  Michael Darling  <darlingm@gmail.com>
+
+	PR binutils/18450
+	* configure: Reflects renaming of configure.in to configure.ac
+	* configure.com: Likewise
+
 2015-07-16  Jiong Wang  <jiong.wang@arm.com>
 
 	* elfnn-aarch64.c (IS_AARCH64_TLS_RELOC): Recognize
diff --git a/bfd/configure b/bfd/configure
index eeeb89a..1ea612b 100755
--- a/bfd/configure
+++ b/bfd/configure
@@ -18338,14 +18338,14 @@ _LT_EOF
           if test -f "$ac_given_srcdir/$ac_dir/LINGUAS"; then
             # The LINGUAS file contains the set of available languages.
             if test -n "$OBSOLETE_ALL_LINGUAS"; then
-              test -n "$as_me" && echo "$as_me: setting ALL_LINGUAS in configure.in is obsolete" || echo "setting ALL_LINGUAS in configure.in is obsolete"
+              test -n "$as_me" && echo "$as_me: setting ALL_LINGUAS in configure.ac is obsolete" || echo "setting ALL_LINGUAS in configure.ac is obsolete"
             fi
             ALL_LINGUAS_=`sed -e "/^#/d" "$ac_given_srcdir/$ac_dir/LINGUAS"`
             # Hide the ALL_LINGUAS assigment from automake.
             eval 'ALL_LINGUAS''=$ALL_LINGUAS_'
             POMAKEFILEDEPS="$POMAKEFILEDEPS LINGUAS"
           else
-            # The set of available languages was given in configure.in.
+            # The set of available languages was given in configure.ac.
             eval 'ALL_LINGUAS''=$OBSOLETE_ALL_LINGUAS'
           fi
           case "$ac_given_srcdir" in
diff --git a/bfd/configure.com b/bfd/configure.com
index 7f7411d..d0e4e02 100644
--- a/bfd/configure.com
+++ b/bfd/configure.com
@@ -184,7 +184,7 @@ $
 $!
 $! create bfdver.h
 $!
-$ write sys$output "Generate `bfdver.h' from 'version.h' and `configure.in'."
+$ write sys$output "Generate `bfdver.h' from 'version.h' and `configure.ac'."
 $ edit/tpu/nojournal/nosection/nodisplay/command=sys$input -
         []version.h /output=[]bfdver.h
 $DECK
@@ -193,7 +193,7 @@ $DECK
 !
 !
    set (success,off);
-   vfile := CREATE_BUFFER("vfile", "configure.in");
+   vfile := CREATE_BUFFER("vfile", "configure.ac");
    rang := CREATE_RANGE(BEGINNING_OF(vfile), END_OF(vfile));
    match_pos := SEARCH_QUIETLY('AC_INIT([bfd], [', FORWARD, EXACT, rang);
    IF match_pos <> 0 THEN;
@@ -265,7 +265,7 @@ $!
 $ write sys$output "Generate `config.h'"
 $ create []config.h
 /* config.h-vms.  Generated by hand by Klaus Kmpf, kkaempf@didymus.rmi.de.  */
-/* config.in.  Generated automatically from configure.in by autoheader.  */
+/* config.in.  Generated automatically from configure.ac by autoheader.  */
 /* Whether malloc must be declared even if <stdlib.h> is included.  */
 /* #undef NEED_DECLARATION_MALLOC */
 /* Whether free must be declared even if <stdlib.h> is included.  */
-- 
2.4.4

